##
##  gd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gd
Summary:      Fast Graphics Generation Library
URL:          http://libgd.org/
Vendor:       Thomas Boutell
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Graphics
License:      GPL
Version:      2.1.1
Release:      20181003

#   package options
%option       with_fontconfig  no

#   list of sources
Source0:      https://bitbucket.org/libgd/gd-libgd/downloads/libgd-%{version}.tar.xz
Patch0:       gd.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101, perl
BuildPreReq:  png, zlib, jpeg, freetype
PreReq:       png, zlib, jpeg, freetype
%if "%{with_fontconfig}" == "yes"
BuildPreReq:  fontconfig, pkgconfig
PreReq:       fontconfig
%endif

%description
    GD is a graphics library. It allows your code to quickly draw images
    complete with lines, arcs, text, multiple colors, cut and paste
    from other images, and flood fills, and write out the result as a
    PNG or JPEG file. This is particularly useful in World Wide Web
    applications, where PNG and JPEG are two of the formats accepted for
    inline images by most browsers.

%track
    prog gd = {
        version   = %{version}
        url       = https://bitbucket.org/libgd/gd-libgd/downloads
        regex     = gd-(\d+\.\d+\.\d+)\.tar\.xz
    }

%prep
    %setup -q -n libgd-%{version}
    %patch -p0
    %{l_shtool} subst \
        -e 's;[ \t]*/usr/local/lib${libsuff};;g' \
        -e 's;[ \t]*-I/usr/local/include;;g' \
        -e 's;[ \t]*/usr/local/include/X11R[4-6];;g' \
        -e 's;[ \t]*/usr/local/include/X11;;g' \
        -e 's;[ \t]*/usr/local/include;;g' \
        -e 's;[ \t]*-L/usr/local/lib;;g' \
        -e 's;[ \t]*/usr/local/lib;;g' \
        -e 's;[ \t]*/usr/local/X11[^/]*/include;;g' \
        -e 's;[ \t]*/usr/local/x11r5/include;;g' \
        configure

%build
    ( echo "ac_cv_header_iconv_h=no"
      echo "am_cv_func_iconv=no"
    ) >config.cache
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags .}" \
    LDFLAGS="%{l_ldflags}" \
%if "%{with_fontconfig}" == "yes"
    LIBS="`pkg-config --libs fontconfig` -lm" \
%else
    LIBS="-lm" \
%endif
    GREP="grep" \
    AUTOCONF="true" \
    ACLOCAL="true" \
    AUTOMAKE="true" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --with-png=%{l_prefix} \
        --with-zlib=%{l_prefix} \
        --with-jpeg=%{l_prefix} \
        --with-freetype=%{l_prefix} \
%if "%{with_fontconfig}" == "yes"
        --with-fontconfig=%{l_prefix} \
%else
        --without-fontconfig \
%endif
        --without-libiconv-prefix \
        --without-vpx \
        --without-tiff \
        --without-xpm \
        --without-x \
        --disable-shared
    %{l_make} %{l_mflags}
    %{l_shtool} subst -e 's;/usr/bin/perl;%{l_prefix}/bin/perl;' bdftogd

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/include/entities.h
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

